Generic orbital mesh generation for all electronic-structure methods.
Provides orbital volumetric grids and isosurface meshes that can be used with any implemented method (EHT, PM3, xTB, HF-3c).
The orbital shape is evaluated using the EHT basis set (STO-nG Gaussians), which provides a good visual representation of molecular orbitals regardless of the method used to determine the MO coefficients and energies.
Structs
- Orbital
Mesh Result - Result of orbital mesh generation including method context.
Enums
- Mesh
Method - Which electronic-structure method to use for orbital mesh generation.
Functions
- compute_
orbital_ mesh - Compute an orbital isosurface mesh for the specified method.