pub struct ReactivityRanking {
pub nucleophilic_attack_sites: Vec<ReactivitySiteScore>,
pub electrophilic_attack_sites: Vec<ReactivitySiteScore>,
pub radical_attack_sites: Vec<ReactivitySiteScore>,
pub notes: Vec<String>,
}Expand description
Empirical local-reactivity ranking summary.
Fields
nucleophilic_attack_sites: Vec<ReactivitySiteScore>Ranked candidate sites for nucleophilic attack on the molecule.
electrophilic_attack_sites: Vec<ReactivitySiteScore>Ranked candidate sites for electrophilic attack on the molecule.
radical_attack_sites: Vec<ReactivitySiteScore>Ranked candidate sites for radical attack on the molecule.
notes: Vec<String>Notes about how scores are constructed.