Module orthogonalization

Module orthogonalization 

Löwdin and canonical orthogonalization of the overlap matrix.

The generalized eigenvalue problem Fc = Scε is converted to a standard eigenvalue problem by orthogonalizing the basis:

F’ = X†FX, F’c’ = c’ε, c = Xc’

where X = S^{-1/2} is the (symmetric) orthogonalization matrix.

Löwdin Orthogonalization

S = UΛU† → S^{-1/2} = UΛ^{-1/2}U†

This preserves the character of the original basis functions as much as possible (least-distortion orthogonalization).

Functions

back_transform
Back-transform coefficients from orthogonal to original basis: C = X C’.
lowdin_orthogonalization
Compute the symmetric orthogonalization matrix X = S^{-1/2}.
transform_to_orthogonal
Transform a matrix to the orthogonal basis: M’ = X† M X.