Structs
- MdFrame
- One trajectory frame for molecular-dynamics sampling.
- MdTrajectory
- Full trajectory output for exploratory molecular dynamics.
- NebImage
- One image (node) on a simplified NEB path.
- NebPath
Result - Simplified NEB output for low-cost pathway exploration.
Enums
- MdBackend
- Force backend for molecular dynamics.
Functions
- atomic_
mass_ amu - compute_
backend_ energy_ and_ gradients - Compute energy and gradients using the specified backend.
- compute_
simplified_ neb_ path - Build a simplified NEB-like path using linear interpolation and spring-coupled relaxation.
- simulate_
nose_ hoover - Nosé-Hoover chain thermostat for rigorous NVT sampling.
- simulate_
velocity_ verlet - Run molecular dynamics using Velocity Verlet with a configurable force backend.
- simulate_
velocity_ verlet_ uff - Run short exploratory molecular dynamics using Velocity Verlet and optional Berendsen NVT.
- trajectory_
to_ xyz - Export an MD trajectory to XYZ format string.